@@ -1,4 +1,5 @@
 __all__ = [
+    'RTBadConfiguration',
     'RTUnknownTypeError',
     'RTInvalidError',
     'RTValueError',
@@ -8,6 +9,10 @@ __all__ = [
 ]
 
 
+class RTBadConfiguration(Exception):
+    pass
+
+
 class RTResourceError(Exception):
     """Default error class """
     status_int = None
